@@ -1,9 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "use-ttf" "0.1.3"
+(define-package "use-ttf" "20260101.603"
   "Keep font consistency across different OSs."
-  '((emacs "24.4"))
+  '((emacs "26.1"))
   :url "https://github.com/jcs-elpa/use-ttf"
-  :commit "3d044b252f48fac5d1f662979b3ac18d80ef27d9"
-  :revdesc "3d044b252f48"
+  :commit "af34fb0d5cc46851b7b567fe171759724b3cdfd4"
+  :revdesc "af34fb0d5cc4"
+  :keywords '("convenience" "customize" "font" "install" "ttf")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
